package VMOMI::DistributedVirtualSwitchHostInfrastructureTrafficClass;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
